# Django KTDatatable View

This package is a base view for handling server side processing for the awesome
[KTDatatable](https://keenthemes.com/metronic/?page=docs&section=html/components/datatable), it simplifies handling of
sorting, filtering and creating JSON output, as defined at [KTDatatable Ajax Response](https://keenthemes.com/metronic/?page=docs&section=html/components/datatable#sec14-6).

[![PyPI Downloads][pypi-dl-image]][pypi-dl-link]
[![PyPI Version][pypi-v-image]][pypi-v-link]

[pypi-dl-link]: https://pypi.python.org/pypi/django-ktdatatable-view
[pypi-dl-image]: https://img.shields.io/pypi/dm/django-ktdatatable-view.png
[pypi-v-link]: https://pypi.python.org/pypi/django-ktdatatable-view
[pypi-v-image]: https://img.shields.io/pypi/v/django-ktdatatable-view.png

## Dependencies:

* [Python](https://www.python.org/) >= 3.6
* [Django](https://www.djangoproject.com/) >= 2.2

## Example

Kuruman is a sample project that uses django-ktdatatable-view
 - https://kuruman.longbowou.com
 - https://gitlab.com/longbowou/kuruman

## Usage

### 1 Install the package:

```bash
pip install django-ktdatatable-view
```